document.addEventListener('DOMContentLoaded', () => {
  const astroForm = document.getElementById('astroForm');
  const resultSection = document.getElementById('result');
  const zodiacSign = document.querySelector('.zodiac-sign');
  const characteristics = document.querySelector('.characteristics');
  const backBtn = document.querySelector('.back-btn');

  const zodiacSigns = {
    'Aries': { date: '03-21', characteristics: 'Confident, courageous, enthusiastic' },
    'Taurus': { date: '04-20', characteristics: 'Reliable, patient, practical' },
    'Gemini': { date: '05-21', characteristics: 'Adaptable, versatile, intellectual' },
    'Cancer': { date: '06-21', characteristics: 'Emotional, loving, intuitive' },
    'Leo': { date: '07-23', characteristics: 'Generous, warm-hearted, creative' },
    'Virgo': { date: '08-23', characteristics: 'Modest, shy, meticulous' },
    'Libra': { date: '09-23', characteristics: 'Diplomatic, romantic, charming' },
    'Scorpio': { date: '10-23', characteristics: 'Determined, powerful, passionate' },
    'Sagittarius': { date: '11-22', characteristics: 'Optimistic, freedom-loving, jovial' },
    'Capricorn': { date: '12-22', characteristics: 'Practical, prudent, ambitious' },
    'Aquarius': { date: '01-20', characteristics: 'Progressive, original, independent' },
    'Pisces': { date: '02-19', characteristics: 'Intuitive, artistic, sympathetic' }
  };

  function getZodiacSign(date) {
    const month = date.getMonth() + 1;
    const day = date.getDate();
    const monthDay = `${month.toString().padStart(2, '0')}-${day.toString().padStart(2, '0')}`;

    let currentSign = 'Capricorn';
    for (const [sign, data] of Object.entries(zodiacSigns)) {
      if (monthDay >= data.date) {
        currentSign = sign;
      }
    }
    return currentSign;
  }

  astroForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const birthDate = new Date(document.getElementById('birthDate').value);
    const birthTime = document.getElementById('birthTime').value;
    const birthPlace = document.getElementById('birthPlace').value;

    const sign = getZodiacSign(birthDate);
    
    zodiacSign.innerHTML = `<h3>Your Zodiac Sign: ${sign}</h3>`;
    characteristics.innerHTML = `
      <h3>Your Characteristics:</h3>
      <p>${zodiacSigns[sign].characteristics}</p>
      <p>Birth Time: ${birthTime}</p>
      <p>Birth Place: ${birthPlace}</p>
    `;

    document.getElementById('birth-form').classList.add('hidden');
    resultSection.classList.remove('hidden');
  });

  backBtn.addEventListener('click', () => {
    document.getElementById('birth-form').classList.remove('hidden');
    resultSection.classList.add('hidden');
    astroForm.reset();
  });
});
